Learn R Programming

panelr (version 1.0.0)

expand_basis_columns: Expand a basis matrix into individual columns in a data frame

Description

Expand a basis matrix into individual columns in a data frame

Usage

expand_basis_columns(data, mat, colnames)

Value

Data frame with added columns

Arguments

data

Data frame to add columns to

mat

Matrix to expand

colnames

Character vector of column names