Logical indicating whether or not to include a confidence
interval in the tidied output. Defaults to FALSE.
conf.level
The confidence level to use for the confidence interval if
conf.int = TRUE. Must be strictly greater than 0 and less than 1. Defaults
to 0.95, which corresponds to a 95 percent confidence interval.
# NOT RUN {data("WageData")
wages <- panel_data(WageData, id = id, wave = t)
model <- fdm(lwage ~ wks + union, data = wages)
if (requireNamespace("broom")) {
broom::tidy(model)
}
# }