Learn R Programming

panelr (version 0.7.2)

tidy.wbm: Tidy methods for wbm models

Description

panelr provides methods to access wbm data in a tidy format

Usage

# S3 method for wbm
tidy(
  x,
  conf.int = FALSE,
  conf.level = 0.95,
  effects = c("fixed", "ran_pars"),
  conf.method = "Wald",
  ran_prefix = NULL,
  ...
)

# S3 method for wbm glance(x, ...)

# S3 method for summ.wbm glance(x, ...)

# S3 method for summ.wbm tidy(x, ...)

Arguments

x

An object of class merMod, such as those from lmer, glmer, or nlmer

conf.int

whether to include a confidence interval

conf.level

confidence level for CI

effects

A character vector including one or more of "fixed" (fixed-effect parameters), "ran_pars" (variances and covariances or standard deviations and correlations of random effect terms) or "ran_modes" (conditional modes/BLUPs/latent variable estimates)

conf.method

method for computing confidence intervals (see lme4::confint.merMod)

ran_prefix

a length-2 character vector specifying the strings to use as prefixes for self- (variance/standard deviation) and cross- (covariance/correlation) random effects terms

...

extra arguments (not used)

Examples

Run this code
# NOT RUN {
data("WageData")
wages <- panel_data(WageData, id = id, wave = t)
model <- wbm(lwage ~ lag(union) + wks, data = wages)
if (requireNamespace("broom")) {
  broom::tidy(model)
}
# }

Run the code above in your browser using DataLab