An object of class merMod, such as those from lmer,
glmer, or nlmer
conf.int
whether to include a confidence interval
conf.level
confidence level for CI
effects
A character vector including one or more of "fixed" (fixed-effect parameters), "ran_pars" (variances and covariances or standard deviations and correlations of random effect terms) or "ran_modes" (conditional modes/BLUPs/latent variable estimates)
conf.method
method for computing confidence intervals (see lme4::confint.merMod)
ran_prefix
a length-2 character vector specifying the strings to use as prefixes for self- (variance/standard deviation) and cross- (covariance/correlation) random effects terms
# NOT RUN {data("WageData")
wages <- panel_data(WageData, id = id, wave = t)
model <- wbm(lwage ~ lag(union) + wks, data = wages)
if (requireNamespace("broom")) {
broom::tidy(model)
}
# }